@@ -1,5 +1,12 @@
+import sys
+
+this = sys.modules[__name__]
+this.flaskApp = None
+
+def set_app(app):
+    this.flaskApp = app
+
 from flask.views import MethodView
-from flask import current_app as app
 
 
 class Watcher(type(MethodView)):
@@ -17,4 +24,4 @@ class RouteView(MethodView, metaclass=Watcher):
         if self.route is not None:
             if self.name is None:
                 self.name = self.__name__
-            app.add_url_rule(self.route, self.name, self.as_view(self.name))
+            this.flaskApp.add_url_rule(self.route, self.name, self.as_view(self.name))
